from mastercardapicore import *

# import apis resourceconfig
from mastercardparametermanagementservices.resourceconfig import ResourceConfig


# import apis into api package
from mastercardparametermanagementservices.partnerstatus import *
